@@ -119,6 +119,16 @@ def init(context):
     scripts.initialise(runner)
 
 
+@click.pass_obj
+def initialise_plugin(context, param):
+    config = grvlms_config.load(context.root)
+    runner = ScriptRunner(context.root, config, context.docker_compose)
+    if param == "init":
+        scripts.initialise_plugin(runner, "init")
+    else:
+        scripts.initialise_plugin(runner, "pre-init")
+
+
 @click.command(
     short_help="Manually trigger hook (advanced users only)",
     help="""
